@@ -9,7 +9,7 @@ use JIP::ClassField;
 use Carp qw(croak);
 use English qw(-no_match_vars);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our @EXPORT_OK = qw(path);
 
@@ -32,7 +32,7 @@ sub new {
 }
 
 sub get {
-    my ($self, $path_parts) = @ARG;
+    my ($self, $path_parts, $default_value) = @ARG;
 
     return $self->document
         if @{ $path_parts } == 0;
@@ -51,7 +51,7 @@ sub get {
         }
     }
 
-    return;
+    return $default_value;
 }
 
 sub contains {
@@ -134,7 +134,7 @@ JIP::DataPath - provides a way to access data elements in a deep, complex and ne
 
 =head1 VERSION
 
-This document describes L<JIP::DataPath> version C<0.02>.
+This document describes L<JIP::DataPath> version C<0.03>.
 
 =head1 SYNOPSIS
 
@@ -184,6 +184,12 @@ Build new L<JIP::DataPath> object.
     # 'bar'
     JIP::DataPath->new(document => ['foo', 'bar'])->get([1]);
 
+    # undef
+    JIP::DataPath->new(document => ['foo', 'bar'])->get([2]);
+
+    # 'default value'
+    JIP::DataPath->new(document => ['foo', 'bar'])->get([2], 'default value');
+
 Extract value from L</"document"> identified by the given path.
 
 =head2 set
@@ -217,6 +223,12 @@ Check if L</"document"> contains a value that can be identified with the given p
     # 42
     JIP::DataPath->new(document => 42)->perform('get', []);
 
+    # undef
+    JIP::DataPath->new(document => 42)->perform('get', ['foo']);
+
+    # 42
+    JIP::DataPath->new(document => 42)->perform('get', ['foo'], 42);
+
     # True
     JIP::DataPath->new(document => 42)->perform('set', [], 100500);
     JIP::DataPath->new(document => 42)->perform('contains', []);
